
(defun dd-start-process (cmd n)
  "Run CMD (a list of strings) in a subprocess. N numbers the various buffers."
  (let*
      ((output-buf (get-buffer-create (format "*dd-output %d*" n)))
       (error-buf  (get-buffer-create (format "*dd-error %d*" n)))
       (done nil)
       exit-status
       result
       (proc-name (format "*dd-proc.out %d*" n))
       (err-proc
	(make-pipe-process
	 :name (format "*dd-proc.err %d*" n)
	 :buffer error-buf
	 :noquery t))
       (out-proc
	(make-process
	 :name proc-name
	 :buffer output-buf
	 :command cmd
	 :noquery t
	 :stderr err-proc)))

    (while (not done)
      (accept-process-output out-proc)

      (cl-ecase (process-status out-proc)
	(run nil)

	(stop
	 (error "process %s stopped" dvc-run-proc-name))

	(exit
	 (setq exit-status (process-exit-status out-proc))

	 (if (zerop exit-status)
	     (setq done 'finish)

	   ;; wait for error pipe to finish writing to error-buf.
	   (while (and
		   (not (eq 'closed (process-status err-proc)))
		   (accept-process-output err-proc)))

	   (setq done 'error)))

	(signal
	 (setq done 'killed))
	))

    ))

(defun dd-test (n)
  "Run dd-start-process n times."
  (interactive "nN: ")
  (let ((i n))
    (while (> i 0)
      (setq i (1- i))
      (dd-start-process '("cat" "debug-process.el") i)
      )))

(dd-test 100)
